# SSL-Lab-seminar-test

SSL-Seminar-test repository:: Topic - Package Test and Deployment

## Synopsis

```python
from ssllabtest import Caculator 

calc = Caculator(isAdd=True,
                 isSub=False,
                 isMul=False,
                 isDiv=False,
                 isRem=False)
sum = calc.adder(1, 2)
print(sum) # sum = 3
```

## Installaion

```bash
$ pip3 install ssllabtest
``` 

Only install module with pip

## Dependancy

- pytest

```bash
$ pip3 install -U pytest
```

## Document Index

1. TDD (Test-Driven Development)
2. From unit-test to module-test
3. Package deployment (using pypi)

